.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

==============================================================================
collective.embeddedpage
==============================================================================

.. image:: https://travis-ci.org/collective/collective.embeddedpage.svg?branch=master
    :target: https://travis-ci.org/collective/collective.embeddedpage

.. image:: https://img.shields.io/pypi/status/collective.embeddedpage.svg
    :target: https://pypi.python.org/pypi/collective.embeddedpage/
    :alt: Egg Status

.. image:: https://img.shields.io/pypi/v/collective.embeddedpage.svg
    :target: https://pypi.python.org/pypi/collective.embeddedpage
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/l/collective.embeddedpage.svg
    :target: https://pypi.python.org/pypi/collective.embeddedpage
    :alt: License

|

.. image:: https://raw.githubusercontent.com/collective/collective.embeddedpage/master/kitconcept.png
   :alt: kitconcept
   :target: https://kitconcept.com/

collective.embeddedpage allows to embed remote HTML pages in Plone.

Features
--------

- Adds EmbeddedPage content types (Dexterity based)
- Displays remote HTML within the view of the EmbeddedPage content object


Examples
--------

This add-on can be seen in action at the following sites:

- Is there a page on the internet where everybody can see the features?


Translations
------------

This product has been translated into

- German


Installation
------------

Install collective.embeddedpage by adding it to your buildout::

    [buildout]

    ...

    eggs =
        collective.embeddedpage


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/collective/collective.embeddedpage/issues
- Source Code: https://github.com/collective/collective.embeddedpage
- Documentation: https://docs.plone.org/foo/bar


Support
-------

If you are having issues,
`please let us know <https://github.com/collective/collective.embeddedpage/issues>`_.

If you require professional support, feel free to drop us a note at info@kitconcept.com.


Credits
-------

.. image:: https://www.hu-berlin.de/++resource++humboldt.logo.Logo.png
   :height: 97px
   :width: 434px
   :scale: 100 %
   :alt: HU Berlin
   :target: https://www.hu-berlin.de

|

The development of this plugin has been kindly sponsored by `Humboldt-Universität zu Berlin`_.

|

.. image:: https://raw.githubusercontent.com/collective/collective.faq/master/kitconcept.png
   :alt: kitconcept
   :target: https://kitconcept.com/

Developed by `kitconcept`_.


License
-------

The project is licensed under the GPLv2.

.. _Humboldt-Universität zu Berlin: https://www.hu-berlin.de
.. _kitconcept: http://www.kitconcept.com/
